@@ -3,6 +3,7 @@ from ._connection import DatabaseConnection, set_gcloud_key_path
 from ._visualize import *
 
 db_connection: DatabaseConnection = None
+db_info = 'sandbox.info'
 
 
 def fetch(*args, **kwargs):
@@ -53,44 +54,39 @@ def list_tables(**kwargs):
 
 def summary(**kwargs):
     global db_connection
-    import pandas as pd
-    all_datasets = list_tables()
-    result = []
-    for dataset_id, tables in all_datasets.items():
-        for table in tables:
-            row = {}
-            temp = db_connection.client.get_table(table.full_table_id.replace(':', '.'))
-            row['dataset'] = dataset_id.split('_')[-1].upper()
-            row['table'] = temp.table_id
-            row['num_rows'] = temp.num_rows
-            row['num_cols'] = len(temp.schema)
-            size = temp.num_bytes
-            for x in ['B', 'KB', 'MB', 'GB', 'TB']:
-                if size < 1024.0:
-                    row['size'] = "%3.1f %s" % (size, x)
-                    break
-                size /= 1024.0
-                row['size'] = size
-            result.append(row)
+    db_connector(**kwargs)
+    client = db_connection.client
+    df = client.query(f"SELECT dataset_name, table_name, num_rows, num_cols, size FROM `{db_info}`").to_dataframe()
 
     print_it = kwargs.get('print')
-    df = pd.DataFrame(result)
     if print_it is None or print_it is True:
+        df['size'] = df['size'].apply(size_to_abbrevation)
         print(df.to_string(index = False))
     return df
 
 
-def visualize(name=None):
-    df = summary(print=False)
+def visualize(**kwargs):
+    name = kwargs.get('dataset')
+    global db_connection
+    db_connector(**kwargs)
+    client = db_connection.client
     if name is None:
-        ds = df.where(df['num_rows'] > 0).dropna()
-        visualize_all(ds)
+        df = client.query(f"""
+                SELECT dataset, dataset_name, table, table_name, num_rows, num_cols, size, treemap
+                FROM `{db_info}`
+                WHERE treemap.show = true AND num_rows > 0""").to_dataframe()
+
+        visualize_all(df)
         return
-    if name.lower() == 'datasets':
-        ds = df.where(df['num_rows'] > 0).groupby('dataset').sum().dropna()
-        visualize_all_datasets(ds)
-        return
-    tables = df.where(df['dataset'] == name.upper()).dropna()
+    df = client.query(f"SELECT dataset_name, table_name, num_rows, num_cols, size FROM `{db_info}`").to_dataframe()
+    tables = df.where(df['dataset_name'] == name.upper()).dropna()
     if len(tables) <= 0:
         return
     visualize_dataset(tables, name)
+
+
+def db_connector(**kwargs):
+    global db_connection
+    if db_connection is None:
+        db_connection = DatabaseConnection(**kwargs)
+    return db_connection
